@@ -142,8 +142,9 @@ class DocumentFileRepository:
 
 
 class DocumentPairRepository:
-    def __init__(self, doc1: models.Document, doc2: models.Document):
+    def __init__(self, doc1: models.Document, doc2: models.Document, lang=None):
         self._docs = {doc1, doc2}
+        self.lang = lang if lang else settings['lang']
 
     def list(self) -> set[models.Document]:
         return self._docs
@@ -211,10 +212,14 @@ class PdfReader:
         self._use_ocr = use_ocr
 
     def extract_urls(self) -> set[str]:
-        with pdfplumber.open(self._file) as pdf:
-            parsed_urls = {urlparse(uri_obj['uri'], "https") for uri_obj in pdf.hyperlinks}
-            return {parsed_url.geturl().rstrip('/').replace("///", "//")
-                    for parsed_url in filter(lambda url: url.scheme in ("http", "https"), parsed_urls)}
+        # Temporary fix for: https://github.com/jsvine/pdfplumber/issues/463
+        try:
+            with pdfplumber.open(self._file) as pdf:
+                parsed_urls = {urlparse(uri_obj['uri'], "https") for uri_obj in pdf.hyperlinks}
+                return {parsed_url.geturl().rstrip('/').replace("///", "//")
+                        for parsed_url in filter(lambda url: url.scheme in ("http", "https"), parsed_urls)}
+        except UnicodeDecodeError:
+            log.warning(f'Could not extract hyperlinks from PDF "{self._file.name}".')
 
     def extract_text(self):
         text = self._extract()
